@@ -55,7 +55,7 @@ def main():
                       help="Relative path to the file containing control flags")
     parser.add_option("--devices", dest="devices", type="string", default='/guest-share/ddr/ddr-devices',
                       help="Relative path to the file containing use case devices")
-    parser.add_option("--tests", dest="tests", type="string", default='/bootflash/guest-share/ddr/ddr-tests',
+    parser.add_option("--tests", dest="tests", type="string", default='/guest-share/ddr/ddr-tests',
                       help="Relative path to the file containing the test facts")
     parser.add_option("--init", dest="init", type="string", default='/guest-share/ddr/ddr-init',
                       help="Absolute path to initial-facts file")
